@@ -14,11 +14,27 @@
 
 import sys
 
+import pbr.version
+
 from os_client_config import cloud_config
 from os_client_config.config import OpenStackConfig  # noqa
 
 
-def simple_client(service_key, cloud=None, region_name=None):
+__version__ = pbr.version.VersionInfo('os_client_config').version_string()
+
+
+def get_config(service_key=None, options=None, **kwargs):
+    config = OpenStackConfig()
+    if options:
+        config.register_argparse_options(options, sys.argv, service_key)
+        parsed_options = options.parse_known_args(sys.argv)
+    else:
+        parsed_options = None
+
+    return config.get_one_cloud(options=parsed_options, **kwargs)
+
+
+def make_rest_client(service_key, options=None, **kwargs):
     """Simple wrapper function. It has almost no features.
 
     This will get you a raw requests Session Adapter that is mounted
@@ -31,8 +47,12 @@ def simple_client(service_key, cloud=None, region_name=None):
     get_session_client on it. This function is to make it easy to poke
     at OpenStack REST APIs with a properly configured keystone session.
     """
-    return OpenStackConfig().get_one_cloud(
-        cloud=cloud, region_name=region_name).get_session_client(service_key)
+    cloud = get_config(service_key=service_key, options=options, **kwargs)
+    return cloud.get_session_client(service_key)
+# Backwards compat - simple_client was a terrible name
+simple_client = make_rest_client
+# Backwards compat - session_client was a terrible name
+session_client = make_rest_client
 
 
 def make_client(service_key, constructor=None, options=None, **kwargs):
@@ -45,14 +65,32 @@ def make_client(service_key, constructor=None, options=None, **kwargs):
     variables and clouds.yaml - and takes as **kwargs anything you'd expect
     to pass in.
     """
+    cloud = get_config(service_key=service_key, options=options, **kwargs)
     if not constructor:
         constructor = cloud_config._get_client(service_key)
-    config = OpenStackConfig()
-    if options:
-        config.register_argparse_options(options, sys.argv, service_key)
-        parsed_options = options.parse_args(sys.argv)
-    else:
-        parsed_options = None
-
-    cloud = config.get_one_cloud(options=parsed_options, **kwargs)
     return cloud.get_legacy_client(service_key, constructor)
+
+
+def make_sdk(options=None, **kwargs):
+    """Simple wrapper for getting an OpenStack SDK Connection.
+
+    For completeness, provide a mechanism that matches make_client and
+    make_rest_client. The heavy lifting here is done in openstacksdk.
+
+    :rtype: :class:`~openstack.connection.Connection`
+    """
+    from openstack import connection
+    cloud = get_config(options=options, **kwargs)
+    return connection.from_config(cloud_config=cloud, options=options)
+
+
+def make_shade(options=None, **kwargs):
+    """Simple wrapper for getting a Shade OpenStackCloud object
+
+    A mechanism that matches make_sdk, make_client and make_rest_client.
+
+    :rtype: :class:`~shade.OpenStackCloud`
+    """
+    import shade
+    cloud = get_config(options=options, **kwargs)
+    return shade.OpenStackCloud(cloud_config=cloud, **kwargs)
